# Nehushtan (נְחֻשְׁתָּן)

A toolkit for projects in Python

<img src="https://github.com/sinri/nehushtan/blob/master/icon.png?raw=true" width="64" height="64"></img>

> ipse dissipavit excelsa et contrivit statuas et succidit lucos confregitque serpentem aeneum quem fecerat Moses siquidem usque ad illud tempus filii Israhel adolebant ei incensum vocavitque eum Naasthan

# History in Brief

* 0.1.2: First version on PYPI with MySQL Toolkit.
* 0.1.3: Add CLI Helper, Logger, SMTP.
* 0.1.4: Changed a lot for projects.
* 0.1.5: Rename `NehushtanArgumentParser`. Revoke the declaration of source root to rebuild the import package.
* 0.1.6: Fix packaging issue.
